@@ -7,8 +7,9 @@ from .ansitowin32 import AnsiToWin32
 orig_stdout = sys.stdout
 orig_stderr = sys.stderr
 
+atexit_done = False
+
 
-@atexit.register
 def reset_all():
     AnsiToWin32(orig_stdout).reset_all()
 
@@ -21,6 +22,11 @@ def init(autoreset=False, convert=None, strip=None, wrap=True):
     sys.stdout = wrap_stream(orig_stdout, convert, strip, autoreset, wrap)
     sys.stderr = wrap_stream(orig_stderr, convert, strip, autoreset, wrap)
 
+    global atexit_done
+    if not atexit_done:
+        atexit.register(reset_all)
+        atexit_done = True
+
 
 def wrap_stream(stream, convert, strip, autoreset, wrap):
     if wrap:
@@ -28,5 +34,4 @@ def wrap_stream(stream, convert, strip, autoreset, wrap):
             convert=convert, strip=strip, autoreset=autoreset)
         if wrapper.should_wrap():
             stream = wrapper.stream
-    return stream
-
+    return stream
\ No newline at end of file
